@@ -47,7 +47,7 @@ class ListResponse(ShipwireResponse):
 
     def _get_all_serial(self):
         # loop over all items with previous and next
-        next = self.next
+        next = self.__next__
         req = self.response.request
         items = self.items
 
@@ -55,8 +55,8 @@ class ListResponse(ShipwireResponse):
             resp = requests.request(req.method, next, auth=self.shipwire.auth)
             list_resp = ListResponse(resp, self.shipwire)
             items.extend(list_resp.items)
-            print next
-            next = list_resp.next
+            print(next)
+            next = list_resp.__next__
 
         return items
 
